microbe.core


<>cljmacro

(<> & forms)

Executes the forms and records the response time with HDR histogram. If the first argument is a keyword, it is used as the series tag (default: :-).

Executes the forms and records the response time with HDR histogram. If the
first argument is a keyword, it is used as the series tag (default: :-).
sourceraw docstring

console-loggerclj

(console-logger point)
source

create-histoclj

(create-histo)
source

default-optionsclj

source

default-tagclj

source

get-or-create-histogramclj

(get-or-create-histogram k)
source

histogram-registryclj

source

runcljmacro

(run & forms)

Starts and stops console metric reporter while evaluating the forms and generates CSV and SVG output of the metrics during the run. If the first argument is a map, it is recognized as the options. See microbe.core/default-options for all supported options.

Starts and stops console metric reporter while evaluating the forms and
generates CSV and SVG output of the metrics during the run. If the first
argument is a map, it is recognized as the options. See
microbe.core/default-options for all supported options.
sourceraw docstring

start-reportingclj

(start-reporting options)
source

stop-reportingclj

(stop-reporting)
source

cljdoc builds & hosts documentation for Clojure/Script libraries