(<> & forms)Executes the forms and records the response time with HDR histogram. If the first argument is a keyword, it is used as the series tag (default: :-).
Executes the forms and records the response time with HDR histogram. If the first argument is a keyword, it is used as the series tag (default: :-).
(run & forms)Starts and stops console metric reporter while evaluating the forms and generates CSV and SVG output of the metrics during the run. If the first argument is a map, it is recognized as the options. See microbe.core/default-options for all supported options.
Starts and stops console metric reporter while evaluating the forms and generates CSV and SVG output of the metrics during the run. If the first argument is a map, it is recognized as the options. See microbe.core/default-options for all supported options.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |